==> ouc_api-1.1.tar.gz: ouc_api-1.1/ouc_api/http.py <==
import requests
import chardet
import random
import socket


class HTTP:
    def __init__(self, timeout=30):
        socket.setdefaulttimeout(timeout)
        self.http = requests.session()
        self.timeout = (10, 20)
        self.headers = {}

    def set_header(self, name, value=""):
        if name is not None and value != "":
            pass
        else:
            self.headers[name] = value

    def set_timeout(self, timeout=15):
        self.timeout = timeout

    def set_user_agent(self, user_gent):
        self.headers["user-agent"] = user_gent

    def get_cookie(self, key=None):
        if key is None:
            return self.http.cookies
        else:
            return self.http.cookies.get(key)

    def get_code(self):
        return self.code

    def get_header(self, key):
        if key:
            return self.http.headers.get(key)
        else:
            return self.http.headers

    def _http_request(self, url, post_data, referer=""):
        if referer:
            self.headers["Referer"] = referer
        if post_data:
            r = self.http.post(url, post_data, headers=self.headers, timeout=self.timeout)
        else:
            r = self.http.get(url, timeout=self.timeout)
        self.code = r.status_code
        encoding = chardet.detect(r.content).get("encoding")
        self.content = r.content.decode(encoding=encoding, errors="ignore")
        return self.content

    def request(self, url, params="", referer=""):
        return self._http_request(url, params, referer)

==> ouc_api-2.1.1.tar.gz: ouc_api-2.1.1/ouc_api/http.py <==
import requests
import chardet
import random
import socket


class HTTP:
    def __init__(self, timeout=30):
        socket.setdefaulttimeout(timeout)
        self.http = requests.session()
        self.http.cookies
        self.timeout = (10, 20)
        self.headers = {}

    def set_header(self, name, value=""):
        if name is not None and value != "":
            pass
        else:
            self.headers[name] = value

    def set_timeout(self, timeout=15):
        self.timeout = timeout

    def set_user_agent(self, user_gent):
        self.headers["user-agent"] = user_gent

    def get_cookie(self, key=None):
        if key is None:
            return self.http.cookies
        else:
            return self.http.cookies.get(key)

    def set_cookie(self, key, val):
        jar = requests.cookies.RequestsCookieJar()
        jar.set(key, val)
        self.http.cookies = jar

    def get_code(self):
        return self.code

    def get_header(self, key):
        if key:
            return self.http.headers.get(key)
        else:
            return self.http.headers

    def _http_request(self, url, post_data, referer="", raw=False):
        if referer:
            self.headers["Referer"] = referer
        if post_data:
            r = self.http.post(url, post_data, headers=self.headers, timeout=self.timeout)
        else:
            r = self.http.get(url, headers=self.headers, timeout=self.timeout)
        self.code = r.status_code
        if raw:
            return r.content
        encoding = chardet.detect(r.content).get("encoding")
        self.content = r.content.decode(encoding=encoding, errors="ignore")
        return self.content

    def request(self, url, params="", referer="", raw=False):
        return self._http_request(url, params, referer, raw)
